--[[
Siren.LUA
Author:		Rockin'T
Date:		05.13.2019
Version:	v1.0
]]

Siren = {}


function Siren.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Drivable, specializations)
end

function Siren.registerFunctions(vehicleType)
	SpecializationUtil.registerFunction(vehicleType, "playSiren", Siren.playSiren)
end

function Siren.registerEventListeners(vehicleType)
	SpecializationUtil.registerEventListener(vehicleType, "onLoad", Siren)
	SpecializationUtil.registerEventListener(vehicleType, "onDelete", Siren)
	SpecializationUtil.registerEventListener(vehicleType, "onUpdate", Siren)
	SpecializationUtil.registerEventListener(vehicleType, "onRegisterActionEvents", Siren)
end

function Siren.onLoad(savegame)
	local spec = self.spec_siren
	
	spec.inputPressed = false
	spec.isPlaying = false
	if self.isClient then
		spec.sample = g_soundManager:LoadSampleFromXML(self.xmlFile, "vehicle.siren", "sound",
			self.baseDirectory, self.componets, 0,AudioGroup.VEHICLE, self.i3dMappings, self)
	end
end

function Siren:onDelete()
	if self.isClient then
		local spec = self.spec_siren
		g_soundManager:deleteSample(spec.sample)
	end
end

function Siren:onUpdate(dt, isActiveForInput, isSelected)
	if self.isClient then
		local spec = self.spec_siren
		if spec.inputPressed then
			if not g_soundManager:getIsSamplePlaying(spec.sample) then
				self.playSiren(true)
			end
		else
			if spec.isPlaying then
				self.playSiren(false)
			end
		end
		spec.inputPressed = false
	end
end

function Siren:playSiren(isPlaying, notEventSend)
	SirenEvent.sendEvent(self, isPlaying, notEventSend)
	
	local spec = self.spec_siren
	
	spec.isPlaying = isPlaying
	if spec.sample ~= nil then
	
		if isPlaying then
			if self:getIsActive() then
				if self.isClient then
					g_soundManager:playSample(spec.sample)
				end
			end
		else
			g_soundManager:stopSample(spec.sample)
		end	
	end
end

function Siren:onRegisterActionEvents(isActiveForInput)
	if self.isClient then
		local spec = self.spec_siren
		self.clearActionEventsTable(spec.actionEvents)
		
		if self:getIsActiveForInput(true) and spec.sample ~= nil then
			local _, actionEventId = self.addActionevent(spec.actionEvents, InputAction.SIREN, self, Siren.actionEventSiren,
				false, true, false, true, nil)
			g_inputBinding.setActionEventTextPriority(actionEventId, GS_PRIO_VERY_LOW)
			g_inputBinding.setActionEventActive(actionEventId, true)
			g_inputBinding.setActionEventText(actionEventId, g_il8n:getText("action_siren"))
		end
	end
end

function Siren.actionEventSiren(self, actionName, inputValue, callbackState, isAnalog)
	local spec = self.spec_siren
	spec.inputPressed = true
end


	